@@ -134,7 +134,7 @@ class Party(models.Model):
     groups = models.ManyToManyField(Group, blank=True)
     connections = models.ManyToManyField(User, blank=True, related_name='party_connections')
     user = models.ForeignKey(User, on_delete=models.CASCADE, blank=True, null=True, related_name='parties')
-    self = models.BooleanField(default=False)
+    individual = models.BooleanField(default=False)
 
     def save(self, *args, **kwargs):
         if not self.id:
