@@ -484,10 +484,11 @@ class StickProtocol():
         success = False
         if user.check_password(data['currentPass']):
             for key in data['preKeys']:
-                preKey = PreKey.objects.get(keyId=key['id'], user=user)
-                preKey.cipher = key['cipher']
-                preKey.salt = key['salt']
-                preKey.save()
+                preKey = PreKey.objects.filter(keyId=key['id'], user=user).first()
+                if preKey:
+                    preKey.cipher = key['cipher']
+                    preKey.salt = key['salt']
+                    preKey.save()
             for key in data['signedPreKeys']:
                 spk = SignedPreKey.objects.get(keyId=key['id'], user=user)
                 spk.cipher = key['cipher']
